@@ -91,21 +91,12 @@ sub _execute_gradle_task {
 	$this->doit_in_builddir("mkdir", "-p", ".gradle/init.d");
 	$this->doit_in_builddir("cp", "/usr/share/gradle-debian-helper/init.gradle", ".gradle/init.d/");
 
-	my $ADD_OPENS = "";
-	if (_check_jpms()) {
-		$ADD_OPENS .= " --add-opens java.base/java.lang=ALL-UNNAMED";
-	}
-
 	# Add the hook to the classpath
 	my $hookClasspath = "/usr/share/java/gradle-helper-hook.jar:/usr/share/java/maven-repo-helper.jar";
 	$ENV{JAVA_OPTS} .= " -Xbootclasspath/a:$hookClasspath";
-	$ENV{JAVA_OPTS} .= " -Dorg.gradle.jvmargs='-Xbootclasspath/a:$hookClasspath $ADD_OPENS'";
+	$ENV{JAVA_OPTS} .= " -Dorg.gradle.jvmargs='-Xbootclasspath/a:$hookClasspath'";
 
 	$this->doit_in_builddir(@{$this->{gradle_cmd}}, @_);
 }
 
-sub _check_jpms {
-	return system("java -cp /usr/share/java/gradle-helper-plugin.jar org.debian.gradle.CheckJPMS") == 0;
-}
-
 1
